package com.gic.finance.service;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.finance.dto.InvoiceManageDTO;
import com.gic.finance.dto.OperationUserInfoDTO;
import com.gic.finance.qo.InvoiceManageListQueryQO;

/**
 * 发票管理
 * @ClassName: InvoiceManageApiService 
 * @Description:  
 * @author guojuxing 
 * @date 2019/8/14 2:41 PM 
 */
public interface InvoiceManageApiService {

    /**
     * 发票申请请求 <br>
     * 商户名称、公司名称、公司logo <br>
     *     这数据如果有，需要传，如果没有，我默认给值 <br>
     * @Title: save 
     * @Description:
      * @author guojuxing
     * @param invoiceManageDTO 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.String> 流水单号
      */
    ServiceResponse<String> applyInvoice(InvoiceManageDTO invoiceManageDTO);

    /**
     * 应用市场开票申请
     * @Title: applyInvoiceForApp 
     * @Description:
      * @author guojuxing
     * @param invoiceManageDTO 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.String> 流水单号
      */
    ServiceResponse<String> applyInvoiceForApp(InvoiceManageDTO invoiceManageDTO);

    /**
     * 开票。待邮寄/邮寄
     * @Title: invoice 
     * @Description:
      * @author guojuxing
     * @param invoiceManageId
     * @param expressMailName
     * @param expressMailNumber 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> invoice(Integer invoiceManageId, String expressMailName, String expressMailNumber, OperationUserInfoDTO dto);

    /**
     * 驳回
     * @Title: rejectInvoice 
     * @Description:
      * @author guojuxing
     * @param invoiceManageId
     * @param rejectReason  驳回理由
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> rejectInvoice(Integer invoiceManageId, String rejectReason, OperationUserInfoDTO dto);

    /**
     * 取消
     * @Title: cancelInvoice 
     * @Description:
      * @author guojuxing
     * @param invoiceManageId 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.String>  返回日志操作对象
      */
    ServiceResponse<String> cancelInvoice(Integer invoiceManageId);

    /**
     * 分页查询发票管理列表
     * @Title: listInvoiceManage 
     * @Description:
      * @author guojuxing
     * @param params 
     * @return  com.gic.api.base.commons.ServiceResponse<com.gic.api.base.commons.Page<com.gic.finance.dto.InvoiceManageDTO>> 
      */
    ServiceResponse<Page<InvoiceManageDTO>> listInvoiceManage(InvoiceManageListQueryQO params);

    /**
     * 详情
     * @Title: getById 
     * @Description:
      * @author guojuxing
     * @param invoiceManageId 
     * @return  com.gic.api.base.commons.ServiceResponse<com.gic.finance.dto.InvoiceManageDTO> 
      */
    ServiceResponse<InvoiceManageDTO> getById(Integer invoiceManageId);

    /**
     * 应用市场取消开票
     * @Title: cancelInvoiceForApp 
     * @Description:
      * @author guojuxing
     * @param initiator 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> cancelInvoiceForApp(String initiator);

}
